@@ -152,8 +152,6 @@ private slots:
     void slotAssignTag(int tagID);
     void slotRemoveTag(int tagID);
 
-    void slotAssignRating(int rating);
-    
     void slotDIOResult(KIO::Job* job);
     
 public slots:
@@ -168,7 +166,15 @@ public slots:
     void slotSetAlbumThumbnail(AlbumIconItem *iconItem);
     void slotCopy();
     void slotPaste();
-    
+
+    void slotAssignRating(int rating);
+    void slotAssignRatingNoStar();
+    void slotAssignRatingOneStar();
+    void slotAssignRatingTwoStar();
+    void slotAssignRatingThreeStar();
+    void slotAssignRatingFourStar();
+    void slotAssignRatingFiveStar();
+        
 signals:
 
     void signalItemsAdded();
