@@ -53,6 +53,7 @@
 #include "albummanager.h"
 #include "digikamapp.h"
 #include "digikamfirstrun.h"
+#include "dcrawbinary.h"
 
 static KCmdLineOptions options[] =
 {
@@ -225,6 +226,9 @@ int main(int argc, char *argv[])
         return app.exec();
     }
 
+    if (!Digikam::DcrawBinary::instance()->checkSystem())
+        return 1;
+
     AlbumManager* man = new AlbumManager();
     man->setLibraryPath(albumPath);
 
