@@ -34,6 +34,7 @@
 #include <kcursor.h>
 #include <klocale.h>
 #include <kstandarddirs.h>
+#include <kapplication.h>
 
 // Digikam includes.
 
@@ -58,14 +59,16 @@ ImageEffect_BWSepia::ImageEffect_BWSepia(QWidget* parent)
 
     QVBoxLayout *topLayout = new QVBoxLayout( plainPage(), 0, spacingHint());
 
-    QVGroupBox *gbox = new QVGroupBox(i18n("Preview"), plainPage());
-    QFrame *frame = new QFrame(gbox);
+    QFrame *frame = new QFrame(plainPage());
     frame->setFrameStyle(QFrame::Panel|QFrame::Sunken);
     QVBoxLayout* l = new QVBoxLayout(frame, 5, 0);
-    m_previewWidget = new Digikam::ImageWidget(480, 320,frame);
-    l->addWidget(m_previewWidget, 0, Qt::AlignCenter);
-    topLayout->addWidget(gbox);
+    m_previewWidget = new Digikam::ImageWidget(480, 320, frame);
+    QWhatsThis::add( m_previewWidget, i18n("<p>This is the black and White conversion tool preview"));
+    l->addWidget(m_previewWidget, 0);
+    topLayout->addWidget(frame);
 
+    // -------------------------------------------------------------
+    
     QHBoxLayout *hlay = new QHBoxLayout(topLayout);
     QLabel *label = new QLabel(i18n("Type:"), plainPage());
     m_typeCB = new QComboBox( false, plainPage() );
@@ -91,11 +94,12 @@ ImageEffect_BWSepia::ImageEffect_BWSepia(QWidget* parent)
                                     "Using this one creates dramatic sky effects and simulates moonlight scenes in daytime.<p>"
                                     "<b>Yellow Filter</b>: simulate black and white film exposure using yellow filter. "
                                     "Most natural tonal correction and improves contrast. Ideal for landscapes.<p>"
-                                    "<b>Sepia Tone</b>: gives a warm highlight and mid-tone while adding a bit of coolness to the "
-                                    "shadows-very similar to the process of bleaching a print and re-developing in a sepia toner.<p>"
+                                    "<b>Sepia Tone</b>: gives a warm highlight and mid-tone while adding a bit of coolness to "
+                                    "the shadows-very similar to the process of bleaching a print and re-developing in a sepia "
+                                    "toner.<p>"
                                     "<b>Brown Tone</b>: more neutral than Sepia Tone filter.<p>"
-                                    "<b>Cold Tone</b>: start subtle and replicate printing on a cold tone black and white paper such "
-                                    "as a bromide enlarging paper.<p>"
+                                    "<b>Cold Tone</b>: start subtle and replicate printing on a cold tone black and white "
+                                    "paper such as a bromide enlarging paper.<p>"
                                     "<b>Selenium Tone</b>: effect that replicate traditional selenium chemical toning done "
                                     "in the darkroom.<p>"
                                     "<b>Platinum Tone</b>: effect that replicate traditional platinum chemical toning done "
@@ -105,8 +109,7 @@ ImageEffect_BWSepia::ImageEffect_BWSepia(QWidget* parent)
     hlay->addWidget(label, 1);
     hlay->addWidget(m_typeCB, 5);
 
-    adjustSize();
-    disableResize();    
+    resize(configDialogSize("Black and White Conversion Dialog"));    
     
     QTimer::singleShot(0, this, SLOT(slotEffect()));
 
@@ -114,16 +117,19 @@ ImageEffect_BWSepia::ImageEffect_BWSepia(QWidget* parent)
 
     connect(m_typeCB, SIGNAL(activated(int)),
             this, SLOT(slotEffect()));
+    
+    connect(m_previewWidget, SIGNAL(signalResized()),
+            this, SLOT(slotEffect()));              
 }
 
 ImageEffect_BWSepia::~ImageEffect_BWSepia()
 {
+    saveDialogSize("Black and White Conversion Dialog");
 }
 
 void ImageEffect_BWSepia::closeEvent(QCloseEvent *e)
 {
     delete m_previewWidget;
-
     e->accept();
 }
 
@@ -135,6 +141,7 @@ QPixmap ImageEffect_BWSepia::previewEffectPic(QString name)
 
 void ImageEffect_BWSepia::slotEffect()
 {
+    kapp->setOverrideCursor( KCursor::waitCursor() );
     Digikam::ImageIface* iface = m_previewWidget->imageIface();
 
     uint * data = iface->getPreviewData();
@@ -150,11 +157,12 @@ void ImageEffect_BWSepia::slotEffect()
     delete [] data;
 
     m_previewWidget->update();
+    kapp->restoreOverrideCursor();
 }
 
 void ImageEffect_BWSepia::slotOk()
 {
-    m_parent->setCursor( KCursor::waitCursor() );
+    kapp->setOverrideCursor( KCursor::waitCursor() );
     Digikam::ImageIface* iface = m_previewWidget->imageIface();
 
     uint* data  = iface->getOriginalData();
@@ -165,14 +173,59 @@ void ImageEffect_BWSepia::slotOk()
        {
        int type = m_typeCB->currentItem();
 
+       QString name;
+       
+       switch (type)
+          {
+          case BWNeutral:
+             name = i18n("Neutral Black && White");
+          break;
+
+          case BWGreenFilter:
+             name = i18n("Black && White With Green Filter");
+          break;
+
+          case BWOrangeFilter:
+             name = i18n("Black && White With Orange Filter");
+          break;
+
+          case BWRedFilter:
+             name = i18n("Black && White With Red Filter");
+          break;
+
+          case BWYellowFilter:
+             name = i18n("Black && White With Yellow Filter");
+          break;
+
+          case BWSepia:
+             name = i18n("Black && White Sepia");
+          break;
+
+          case BWBrown:
+             name = i18n("Black && White Brown");
+          break;
+
+          case BWCold:
+             name = i18n("Black && White Cold");
+          break;
+
+          case BWSelenium:
+             name = i18n("Black && White Selenium");
+          break;
+          
+          case BWPlatinum:
+             name = i18n("Black && White Platinum");
+          break;
+          }
+          
        blackAndWhiteConversion(data, w, h, type);
 
-       iface->putOriginalData(i18n("Black & White"), data);
+       iface->putOriginalData(name, data);
 
        delete [] data;
        }
 
-    m_parent->setCursor( KCursor::arrowCursor() );
+    kapp->restoreOverrideCursor();
     accept();
 }
 
