@@ -1,9 +1,9 @@
 /* ============================================================
  * Author: Gilles Caulier <caulier dot gilles at free.fr>
  * Date  : 2004-07-11
- * Description : RGB adjustement plugin for ImageEditor
+ * Description : digiKam image editor Color Balance tool.
  * 
- * Copyright 2004 by Gilles Caulier
+ * Copyright 2004-2005 by Gilles Caulier
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -43,6 +43,10 @@ public:
     ImageEffect_RGB(QWidget *parent);
     ~ImageEffect_RGB();
 
+protected:
+
+    void closeEvent(QCloseEvent *e);
+        
 private:
 
     QSpinBox             *m_rInput;
