@@ -97,6 +97,7 @@ private:
     CameraController* m_controller;
     
     KURL              m_lastDestURL;
+    QStringList       m_foldersToScan;
 
 private slots:
 
@@ -132,6 +133,7 @@ signals:
     
     void signalLastDestination(const KURL&);
     void signalAlbumSettingsChanged();
+    void close();
 };
 
 #endif /* CAMERAUI_H */
