@@ -43,6 +43,7 @@
 #include <qvbuttongroup.h>
 #include <qcolor.h>
 #include <qcombobox.h>
+#include <qstyle.h>
 
 // KDE lib includes
 
@@ -84,6 +85,10 @@ ImageEditorPrintDialogPage::ImageEditorPrintDialogPage( QWidget *parent, const c
     m_blackwhite->setChecked( false );
     layout->addWidget (m_blackwhite );
 
+    m_autoRotate = new QCheckBox( i18n("&Auto-rotate page"), this );
+    m_autoRotate->setChecked( false );
+    layout->addWidget( m_autoRotate );
+
     QVButtonGroup *group = new QVButtonGroup( i18n("Scaling"), this );
     group->setRadioButtonExclusive( true );
     layout->addWidget( group );
@@ -91,34 +96,31 @@ ImageEditorPrintDialogPage::ImageEditorPrintDialogPage( QWidget *parent, const c
     m_scaleToFit = new QRadioButton( i18n("Scale image to &fit"), group );
     m_scaleToFit->setChecked( true );
 
-    QWidget *widget = new QWidget( group );
-    QGridLayout *grid = new QGridLayout( widget, 3, 3 );
-    grid->addColSpacing( 0, 30 );
-    grid->setColStretch( 0, 0 );
-    grid->setColStretch( 1, 1 );
-    grid->setColStretch( 2, 10 );
-
-    m_scale = new QRadioButton( i18n("Print e&xact size: "), widget );
-    grid->addMultiCellWidget( m_scale, 0, 0, 0, 1 );
-    group->insert( m_scale );
+    m_scale = new QRadioButton( i18n("Print e&xact size: "), group );
     
     connect( m_scale, SIGNAL( toggled( bool )),
              SLOT( toggleScaling( bool )));
 
-    m_units = new KComboBox( false, widget, "unit combobox" );
-    grid->addWidget( m_units, 0, 2, AlignLeft );
+    QHBox *hb = new QHBox( group );
+    layout->addWidget( hb );
+    hb->setSpacing( KDialog::spacingHint() );
+    QWidget *w = new QWidget(hb);
+    w->setFixedWidth(m_scale->style().subRect( QStyle::SR_RadioButtonIndicator, m_scale ).width());
+
+    m_width = new KDoubleNumInput( hb, "exact width" );
+    m_width->setMinValue( 1 );
+
+    new QLabel( "x", hb );
+
+    m_height = new KDoubleNumInput( hb, "exact height" );
+    m_height->setMinValue( 1 );
+
+    m_units = new KComboBox( false, hb, "unit combobox" );
     m_units->insertItem( i18n("Centimeters") );
     m_units->insertItem( i18n("Inches") );
 
-    m_width = new KDoubleNumInput( widget, "exact width" );
-    grid->addWidget( m_width, 1, 1 );
-    m_width->setLabel( i18n("&Width:" ) );
-    m_width->setMinValue( 1 );
-
-    m_height = new KDoubleNumInput( widget, "exact height" );
-    grid->addWidget( m_height, 2, 1 );
-    m_height->setLabel( i18n("&Height:" ) );
-    m_height->setMinValue( 1 );
+    w = new QWidget(hb);
+    hb->setStretchFactor( w, 1 );
 }
 
 ImageEditorPrintDialogPage::~ImageEditorPrintDialogPage()
@@ -138,6 +140,7 @@ void ImageEditorPrintDialogPage::getOptions( QMap<QString,QString>& opts,
     opts["app-imageeditor-scale-unit"] = m_units->currentText();
     opts["app-imageeditor-scale-width"] = QString::number( m_width->value() );
     opts["app-imageeditor-scale-height"] = QString::number( m_height->value() );
+    opts["app-imageeditor-auto-rotate"] = m_autoRotate->isChecked() ? t : f;
 }
 
 
@@ -153,6 +156,7 @@ void ImageEditorPrintDialogPage::setOptions( const QMap<QString,QString>& opts )
     m_blackwhite->setChecked ( false );
     m_scaleToFit->setChecked( opts["app-imageeditor-scaleToFit"] != f );
     m_scale->setChecked( opts["app-imageeditor-scale"] == t );
+    m_autoRotate->setChecked( opts["app-imageeditor-auto-rotate"] == t );
 
     m_units->setCurrentItem( opts["app-imageeditor-scale-unit"] );
 
@@ -222,9 +226,11 @@ bool ImagePrint::printImageWithQt()
     QFontMetrics fm = p.fontMetrics();
 
 
+    int w, h; // will be set to the width and height of the printer
+              // when the orientation is decided.
     int filenameOffset = 0;
-    int w = metrics.width();
-    int h = metrics.height();
+
+    QSize size = m_image.size();
 
     bool printFilename = m_printer.option( "app-imageeditor-printFilename" ) != f;
     if ( printFilename )
@@ -237,8 +243,16 @@ bool ImagePrint::printImageWithQt()
     if ( m_printer.option( "app-imageeditor-scaleToFit" ) != f )
     {
         
+        if ( m_printer.option( "app-imageeditor-auto-rotate" ) == t )
+            m_printer.setOrientation( size.width() <= size.height() ? KPrinter::Portrait : KPrinter::Landscape );
+
+        if ( m_printer.option( "app-imageeditor-auto-rotate" ) == t )
+            m_printer.setOrientation( size.width() <= size.height() ? KPrinter::Portrait : KPrinter::Landscape );
+
         // Scale image to fit pagesize
-        m_image = m_image.smoothScale( w, h, QImage::ScaleMin );
+        w = metrics.width();
+        h = metrics.height();
+        size.scale( w, h, QSize::ScaleMin );
     }
     else
     {
@@ -246,6 +260,13 @@ bool ImagePrint::printImageWithQt()
         QString unit  = m_printer.option("app-imageeditor-scale-unit");
         double  wunit = m_printer.option("app-imageeditor-scale-width").toDouble();
         double  hunit = m_printer.option("app-imageeditor-scale-height").toDouble();
+
+        if ( m_printer.option( "app-imageeditor-auto-rotate" ) == t )
+            m_printer.setOrientation( wunit <= hunit ? KPrinter::Portrait : KPrinter::Landscape );
+
+        w = metrics.width();
+        h = metrics.height();
+
         int     wresize, hresize;
         if (unit == i18n("Centimeters"))
         {
@@ -260,7 +281,7 @@ bool ImagePrint::printImageWithQt()
             hresize  = (int)(metrics.logicalDpiY() * hunit);
         }
 
-        m_image = m_image.smoothScale( wresize, hresize, QImage::ScaleMin );
+        size.scale( wresize, hresize, QSize::ScaleMin );
     }
 
     // Align image.
@@ -280,22 +301,22 @@ bool ImagePrint::printImageWithQt()
 
     // x - alignment
     if ( alignment & Qt::AlignHCenter )
-        x = (w - m_image.width())/2;
+        x = (w - size.width())/2;
     else if ( alignment & Qt::AlignLeft )
         x = 0;
     else if ( alignment & Qt::AlignRight )
-        x = w - m_image.width();
+        x = w - size.width();
 
     // y - alignment
     if ( alignment & Qt::AlignVCenter )
-        y = (h - m_image.height())/2;
+        y = (h - size.height())/2;
     else if ( alignment & Qt::AlignTop )
         y = 0;
     else if ( alignment & Qt::AlignBottom )
-        y = h - m_image.height();
+        y = h - size.height();
 
     // Perform the actual drawing.
-    p.drawImage( x, y, m_image );
+    p.drawImage( QRect( x, y, size.width(), size.height()), m_image );;
 
     if ( printFilename )
     {
