@@ -5,6 +5,7 @@
  * Description :
  *
  * Copyright 2004-2005 by Renchi Raju, Gilles Caulier
+ * Copyright 2006 by Gilles Caulier
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -101,6 +102,7 @@ ImageWindow::ImageWindow()
     m_allowSaving           = true;
     m_fullScreen            = false;
     m_fullScreenHideToolBar = false;
+    m_isReadOnly            = false;
     m_view                  = 0L;
     
     // -- construct the view ---------------------------------
@@ -548,7 +550,7 @@ void ImageWindow::slotLoadCurrent()
 
         QApplication::setOverrideCursor(Qt::WaitCursor);
 
-        m_canvas->load(m_urlCurrent.path());
+        m_isReadOnly = m_canvas->load(m_urlCurrent.path());
         m_rotatedOrFlipped = false;
 
         QString text = m_urlCurrent.filename() +
@@ -960,11 +962,6 @@ void ImageWindow::slotFilePrint()
     }
 }
 
-void ImageWindow::slotSave()
-{
-    save();
-}
-
 bool ImageWindow::save()
 {
     kapp->setOverrideCursor( KCursor::waitCursor() );
@@ -1010,12 +1007,12 @@ bool ImageWindow::save()
     
     m_canvas->setModified( false );
     emit signalFileModified(m_urlCurrent);
-    QTimer::singleShot(0, this, SLOT(slotLoadCurrent()));
+    slotLoadCurrent();
     kapp->restoreOverrideCursor();
     return true;
 }
 
-void ImageWindow::slotSaveAs()
+bool ImageWindow::saveAs()
 {
     // Get the new filename.
 
@@ -1034,22 +1031,54 @@ void ImageWindow::slotSaveAs()
 
     imageFileSaveDialog.setOperationMode( KFileDialog::Saving );
     imageFileSaveDialog.setMode( KFile::File );
+    imageFileSaveDialog.setSelection(m_urlCurrent.fileName());    
     imageFileSaveDialog.setCaption( i18n("New Image File Name") );
     imageFileSaveDialog.setMimeFilter(mimetypes);
 
     // Check for cancel.
     if ( imageFileSaveDialog.exec() != KFileDialog::Accepted )
     {
-       return;
+       return false;
     }
 
     KURL newURL = imageFileSaveDialog.selectedURL();
+
+    // Check if target image format have been selected from Combo List of SaveAs dialog.
     QString format = KImageIO::typeForMime(imageFileSaveDialog.currentMimeFilter());
-    if (format.isEmpty())
+
+    if ( format.isEmpty() )
     {
-        // if the format is empty then file format is same as that of the
-        // original file
-        format = QImageIO::imageFormat(m_urlCurrent.path());
+        // Else, check if target image format have been add to target image file name using extension.
+
+        QFileInfo fi(newURL.path());
+        format = fi.extension(false);
+        
+        if ( format.isEmpty() )
+        {
+            // If format is empty then file format is same as that of the original file.
+            format = QImageIO::imageFormat(m_urlCurrent.path());
+        }
+        else
+        {
+            // Else, check if format from file name extension is include on file mime type list.
+
+            QString imgExtPattern;
+            for (QStringList::ConstIterator it = mimetypes.begin() ; it != mimetypes.end() ; it++)
+            {    
+                imgExtPattern.append (KImageIO::typeForMime(*it).upper());
+                imgExtPattern.append (" ");
+            }    
+            if ( imgExtPattern.contains("TIFF") ) imgExtPattern.append (" TIF");
+            if ( imgExtPattern.contains("JPEG") ) imgExtPattern.append (" JPG");
+    
+            if ( !imgExtPattern.contains( format.upper() ) )
+            {
+                KMessageBox::error(this, i18n("Target image file format \"%1\" unsupported!")
+                        .arg(format));
+                kdWarning() << k_funcinfo << "target image file format " << format << " unsupported!" << endl;
+                return false;
+            }
+        }
     }
     
     if (!newURL.isValid())
@@ -1058,7 +1087,7 @@ void ImageWindow::slotSaveAs()
                            .arg(newURL.filename())
                            .arg(newURL.path().section('/', -2, -2)));
         kdWarning() << k_funcinfo << "target URL isn't valid !" << endl;
-        return;
+        return false;
     }
 
     // if new and original url are save use slotSave() ------------------------------
@@ -1070,7 +1099,7 @@ void ImageWindow::slotSaveAs()
     if (currURL.equals(newURL))
     {
         slotSave();
-        return;
+        return false;
     }
 
     // Check for overwrite ----------------------------------------------------------
@@ -1091,7 +1120,7 @@ void ImageWindow::slotSaveAs()
                                        KStdGuiItem::cancel() );
 
         if (result != KMessageBox::Yes)
-            return;
+            return false;
 
         fileExists = true;
     }
@@ -1113,7 +1142,7 @@ void ImageWindow::slotSaveAs()
                            .arg(newURL.filename())
                            .arg(newURL.path().section('/', -2, -2)));
 
-        return;
+        return false;
     }
 
     // only try to write exif if both src and destination are jpeg files
@@ -1145,7 +1174,7 @@ void ImageWindow::slotSaveAs()
         kapp->restoreOverrideCursor();
         KMessageBox::error(this, i18n("Failed to save to new file"),
                            i18n("Error Saving File"));
-        return;
+        return false;
     }
 
     // Find the src and dest albums ------------------------------------------
@@ -1156,7 +1185,7 @@ void ImageWindow::slotSaveAs()
     {
         kapp->restoreOverrideCursor();
         kdWarning() << k_funcinfo << "Cannot find the source album" << endl;
-        return;
+        return false;
     }
 
     KURL dstDirURL(QDir::cleanDirPath(newURL.directory()));
@@ -1165,7 +1194,7 @@ void ImageWindow::slotSaveAs()
     {
         kapp->restoreOverrideCursor();
         kdWarning() << k_funcinfo << "Cannot find the destination album" << endl;
-        return;
+        return false;
     }
         
     // Now copy the metadata of the original file to the new file ------------
@@ -1191,7 +1220,8 @@ void ImageWindow::slotSaveAs()
 
     m_canvas->setModified( false );
     kapp->restoreOverrideCursor();
-    QTimer::singleShot(0, this, SLOT(slotLoadCurrent()));
+    slotLoadCurrent();
+    return true;
 }
 
 void ImageWindow::slotToggleFullScreen()
@@ -1309,10 +1339,14 @@ bool ImageWindow::promptUserSave()
                                             KStdGuiItem::discard());
         if (result == KMessageBox::Yes)
         {
-            return save();
+            if (m_isReadOnly)
+                return saveAs();
+            else
+                return save();
         }
         else if (result == KMessageBox::No)
         {
+            m_saveAction->setEnabled(false);
             return true;
         }
         else
