@@ -1,7 +1,8 @@
 /* ============================================================
  * Author: Renchi Raju <renchi@pooh.tam.uiuc.edu>
+ *         Jrn Ahrens <joern.ahrens@kdemail.net>
  * Date  : 2005-02-06
- * Copyright 2005 by Renchi Raju
+ * Copyright 2005 by Renchi Raju, Jrn Ahrens
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -23,6 +24,7 @@
 class UndoManagerPriv;
 class UndoAction;
 class UndoCache;
+class QStringList;
 
 namespace Digikam
 {
@@ -37,15 +39,26 @@ public:
     ~UndoManager();
 
     void undo();
+    void redo();
+    
     void clear(bool clearCache=true);
     bool anyMoreUndo();
+    bool anyMoreRedo();    
+    void getUndoHistory(QStringList &titles);
+    void getRedoHistory(QStringList &titles);
 
     void addAction(UndoAction* action);
 
 private:
+    
+    void clearUndoActions();
+    void clearRedoActions();
 
     Digikam::ImlibInterface* m_iface;
-    QValueList<UndoAction*>  m_actions;
+    
+    QValueList<UndoAction*>  m_undoActions;
+    QValueList<UndoAction*>  m_redoActions;
+    
     UndoCache*               m_cache;
 };
 
